---
name: New process parameter
about: Propose a new process parameter
title: "[process id]: [parameter summary]"
labels: enhancement, minor
assignees: ''

---

**Proposed Process ID:** ... (alphanumeric + underscore only)
**Proposed Parameter Name:** ... (alphanumeric + underscore only)
**Optional:** yes, default: ...

## Context
Give some context and an introduction of what this parameter is needed for, e.g. use cases.

## Description
... (Markdown allowed)

## Data Type
boolean/number/string/array/object/null
... (include additional constraints, e.g. min/max values for numbers or a list of allowed values for strings)

## Additional changes
If required describe any additional changes that are required for the parameter, e.g. an additional data type for the return value, an additional example, an additional link to explain the parameter, etc.
